mangadap.contrib.LambdaR\_2D\_forMaNGA module
=============================================

.. automodule:: mangadap.contrib.LambdaR_2D_forMaNGA
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
